==> huaweicloudsdkswr-3.1.86-py2.py3-none-any.whl: huaweicloudsdkswr/v2/model/tag_selector.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TagSelector:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'kind': 'str',
        'pattern': 'str'
    }

    attribute_map = {
        'kind': 'kind',
        'pattern': 'pattern'
    }

    def __init__(self, kind=None, pattern=None):
        """TagSelector

        The model defined in huaweicloud sdk

        :param kind: 匹配规则，label、regexp
        :type kind: str
        :param pattern: kind是label时，设置为镜像版本,kind是regexp时，设置为正则表达式
        :type pattern: str
        """
        
        

        self._kind = None
        self._pattern = None
        self.discriminator = None

        self.kind = kind
        self.pattern = pattern

    @property
    def kind(self):
        """Gets the kind of this TagSelector.

        匹配规则，label、regexp

        :return: The kind of this TagSelector.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this TagSelector.

        匹配规则，label、regexp

        :param kind: The kind of this TagSelector.
        :type kind: str
        """
        self._kind = kind

    @property
    def pattern(self):
        """Gets the pattern of this TagSelector.

        kind是label时，设置为镜像版本,kind是regexp时，设置为正则表达式

        :return: The pattern of this TagSelector.
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        """Sets the pattern of this TagSelector.

        kind是label时，设置为镜像版本,kind是regexp时，设置为正则表达式

        :param pattern: The pattern of this TagSelector.
        :type pattern: str
        """
        self._pattern = pattern

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagSelector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkswr-3.1.145-py2.py3-none-any.whl: huaweicloudsdkswr/v2/model/tag_selector.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class TagSelector:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'kind': 'str',
        'pattern': 'str'
    }

    attribute_map = {
        'kind': 'kind',
        'pattern': 'pattern'
    }

    def __init__(self, kind=None, pattern=None):
        r"""TagSelector

        The model defined in huaweicloud sdk

        :param kind: 匹配规则，label、regexp
        :type kind: str
        :param pattern: kind是label时，设置为镜像版本,kind是regexp时，设置为正则表达式
        :type pattern: str
        """
        
        

        self._kind = None
        self._pattern = None
        self.discriminator = None

        self.kind = kind
        self.pattern = pattern

    @property
    def kind(self):
        r"""Gets the kind of this TagSelector.

        匹配规则，label、regexp

        :return: The kind of this TagSelector.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        r"""Sets the kind of this TagSelector.

        匹配规则，label、regexp

        :param kind: The kind of this TagSelector.
        :type kind: str
        """
        self._kind = kind

    @property
    def pattern(self):
        r"""Gets the pattern of this TagSelector.

        kind是label时，设置为镜像版本,kind是regexp时，设置为正则表达式

        :return: The pattern of this TagSelector.
        :rtype: str
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        r"""Sets the pattern of this TagSelector.

        kind是label时，设置为镜像版本,kind是regexp时，设置为正则表达式

        :param pattern: The pattern of this TagSelector.
        :type pattern: str
        """
        self._pattern = pattern

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TagSelector):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
